# Earthformer

[![image](https://img.shields.io/pypi/v/earthformer.svg)](https://pypi.python.org/pypi/earthformer)
[![image](https://img.shields.io/conda/vn/conda-forge/earthformer.svg)](https://anaconda.org/conda-forge/earthformer)

**A Python package for Earthformer**

-   Free software: Apache Software License 2.0
-   Documentation: <https://opengeos.github.io/earthformer>

## Introduction

Earthformer is a Python package for the [Earth forecasting transformer](https://github.com/amazon-science/earth-forecasting-transformer).

## Installation

```bash
pip install earthformer
```
